(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     18339,        449]
NotebookOptionsPosition[     18771,        440]
NotebookOutlinePosition[     19236,        460]
CellTagsIndexPosition[     19193,        457]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Particle Equilibrium in 3D\n",
 StyleBox["Zhelong He, Marek-Jerzy Pindera \nUniversity of Virginia, \
2018-10-13",
  FontSize->16,
  FontColor->GrayLevel[0]]
}], "Title",
 TextAlignment->Center],

Cell[TextData[{
 "In this module we show the particle equilibrium in 3D. Similar to the 2D \
case, the particle can only be in equilibrium when the resultant force is 0, \
which means the three components of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "R"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " should all be zero. "
}], "Text"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`fr$$ = 0, $CellContext`fx1$$ = 
    10, $CellContext`fx2$$ = -10, $CellContext`fx3$$ = -10, \
$CellContext`fy1$$ = 10, $CellContext`fy2$$ = 
    10, $CellContext`fy3$$ = -10, $CellContext`fz1$$ = 0, $CellContext`fz2$$ =
     0, $CellContext`fz3$$ = 0, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`fx1$$], 10, 
       Row[{
         Style[
          Subscript[
          "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "x1"], Bold, 
          12]}]}, -10, 10}, {{
       Hold[$CellContext`fy1$$], 10, 
       Row[{
         Style[
          Subscript[
          "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "y1"], Bold, 
          12]}]}, -10, 10}, {{
       Hold[$CellContext`fz1$$], 0, 
       Row[{
         Style[
          Subscript[
          "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "z1"], Bold, 
          12]}]}, -10, 10}, {{
       Hold[$CellContext`fx2$$], -10, 
       Row[{
         Style[
          Subscript[
          "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "x2"], Bold, 
          12]}]}, -10, 10}, {{
       Hold[$CellContext`fy2$$], 10, 
       Row[{
         Style[
          Subscript[
          "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "y2"], Bold, 
          12]}]}, -10, 10}, {{
       Hold[$CellContext`fz2$$], 0, 
       Row[{
         Style[
          Subscript[
          "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "z2"], Bold, 
          12]}]}, -10, 10}, {{
       Hold[$CellContext`fx3$$], -10, 
       Row[{
         Style[
          Subscript[
          "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "x3"], Bold, 
          12]}]}, -10, 10}, {{
       Hold[$CellContext`fy3$$], -10, 
       Row[{
         Style[
          Subscript[
          "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "y3"], Bold, 
          12]}]}, -10, 10}, {{
       Hold[$CellContext`fz3$$], 0, 
       Row[{
         Style[
          Subscript[
          "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "z3"], Bold, 
          12]}]}, -10, 10}, {
      Hold[
       Grid[{{
          Manipulate`Place[1], 
          Manipulate`Place[2], 
          Manipulate`Place[3]}, {
          Manipulate`Place[4], 
          Manipulate`Place[5], 
          Manipulate`Place[6]}, {
          Manipulate`Place[7], 
          Manipulate`Place[8], 
          Manipulate`Place[9]}}, Alignment -> Left, Spacings -> {0.8, 0.4}]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`fr$$], 0, 
       Row[{
         Style[
          Subscript["\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "R"],
           Bold, 12]}]}, {1 -> "On", 0 -> "Off"}}, {
      Hold[
       Grid[{{
          Manipulate`Place[10], 
          PaneSelector[{1 -> Row[{
               Spacer[20], 
               Style[
                Subscript[
                "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "Rx"], 
                Bold, 12], 
               Spacer[5], "=", 
               Spacer[5], 
               
               Dynamic[$CellContext`fx1$$ + $CellContext`fx2$$ + \
$CellContext`fx3$$], 
               Spacer[20], 
               Style[
                Subscript[
                "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "Ry"], 
                Bold, 12], 
               Spacer[5], "=", 
               Spacer[5], 
               
               Dynamic[$CellContext`fy1$$ + $CellContext`fy2$$ + \
$CellContext`fy3$$], 
               Spacer[20], 
               Style[
                Subscript[
                "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "Rz"], 
                Bold, 12], 
               Spacer[5], "=", 
               Spacer[5], 
               
               Dynamic[$CellContext`fz1$$ + $CellContext`fz2$$ + \
$CellContext`fz3$$]}]}, 
           Dynamic[$CellContext`fr$$]], 
          Spacer[20], 
          PaneSelector[{{0, 0, 0} -> Style["Balanced", Bold, 12, 
              RGBColor[0, 
               Rational[2, 3], 0]]}, 
           
           Dynamic[{$CellContext`fx1$$ + $CellContext`fx2$$ + \
$CellContext`fx3$$, $CellContext`fy1$$ + $CellContext`fy2$$ + \
$CellContext`fy3$$, $CellContext`fz1$$ + $CellContext`fz2$$ + \
$CellContext`fz3$$}]]}}]], Manipulate`Dump`ThisIsNotAControl}}, 
    Typeset`size$$ = {747., {353., 362.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`fx1$42432$$ = 0, $CellContext`fy1$42433$$ = 
    0, $CellContext`fz1$42434$$ = 0, $CellContext`fx2$42435$$ = 
    0, $CellContext`fy2$42436$$ = 0, $CellContext`fz2$42437$$ = 
    0, $CellContext`fx3$42438$$ = 0, $CellContext`fy3$42439$$ = 
    0, $CellContext`fz3$42440$$ = 0, $CellContext`fr$42441$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`fr$$ = 0, $CellContext`fx1$$ = 
        10, $CellContext`fx2$$ = -10, $CellContext`fx3$$ = -10, \
$CellContext`fy1$$ = 10, $CellContext`fy2$$ = 
        10, $CellContext`fy3$$ = -10, $CellContext`fz1$$ = 
        0, $CellContext`fz2$$ = 0, $CellContext`fz3$$ = 0}, 
      "ControllerVariables" :> {
        Hold[$CellContext`fx1$$, $CellContext`fx1$42432$$, 0], 
        Hold[$CellContext`fy1$$, $CellContext`fy1$42433$$, 0], 
        Hold[$CellContext`fz1$$, $CellContext`fz1$42434$$, 0], 
        Hold[$CellContext`fx2$$, $CellContext`fx2$42435$$, 0], 
        Hold[$CellContext`fy2$$, $CellContext`fy2$42436$$, 0], 
        Hold[$CellContext`fz2$$, $CellContext`fz2$42437$$, 0], 
        Hold[$CellContext`fx3$$, $CellContext`fx3$42438$$, 0], 
        Hold[$CellContext`fy3$$, $CellContext`fy3$42439$$, 0], 
        Hold[$CellContext`fz3$$, $CellContext`fz3$42440$$, 0], 
        Hold[$CellContext`fr$$, $CellContext`fr$42441$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`t$, $CellContext`ts$, $CellContext`te$, \
$CellContext`fac$, $CellContext`ax$, $CellContext`ay$, $CellContext`az$, \
$CellContext`px$, $CellContext`py$, $CellContext`pz$, $CellContext`x$, \
$CellContext`y$, $CellContext`z$, $CellContext`dw$, $CellContext`an$, \
$CellContext`size$, $CellContext`r$ = 1}, $CellContext`ts$ = 
         0; $CellContext`te$ = 15; $CellContext`fac$ = 10; $CellContext`size$ = 
         300; $CellContext`ax$ = ($CellContext`fx1$$ + $CellContext`fx2$$ + \
$CellContext`fx3$$)/$CellContext`r$^2; $CellContext`ay$ = ($CellContext`fy1$$ + \
$CellContext`fy2$$ + $CellContext`fy3$$)/$CellContext`r$^2; $CellContext`az$ = \
($CellContext`fz1$$ + $CellContext`fz2$$ + \
$CellContext`fz3$$)/$CellContext`r$^2; $CellContext`x$ = NDSolveValue[{D[
              $CellContext`px$[$CellContext`t$], {$CellContext`t$, 
               2}] == $CellContext`ax$, $CellContext`px$[0] == 0, 
            Derivative[1][$CellContext`px$][0] == 
            0}, $CellContext`px$, {$CellContext`t$, $CellContext`ts$, \
$CellContext`te$}]; $CellContext`y$ = NDSolveValue[{D[
              $CellContext`py$[$CellContext`t$], {$CellContext`t$, 
               2}] == $CellContext`ay$, $CellContext`py$[0] == 0, 
            Derivative[1][$CellContext`py$][0] == 
            0}, $CellContext`py$, {$CellContext`t$, $CellContext`ts$, \
$CellContext`te$}]; $CellContext`z$ = NDSolveValue[{D[
              $CellContext`pz$[$CellContext`t$], {$CellContext`t$, 
               2}] == $CellContext`az$, $CellContext`pz$[0] == 0, 
            Derivative[1][$CellContext`pz$][0] == 
            0}, $CellContext`pz$, {$CellContext`t$, $CellContext`ts$, \
$CellContext`te$}]; $CellContext`dwf1 = {
           Opacity[1], 
           Dashing[{}], 
           Thickness[0.0025], 
           Arrowheads[0.02], 
           
           Arrow[{{(-1.2) $CellContext`size$, 0, 0}, {
             1.2 $CellContext`size$, 0, 0}}], 
           
           Arrow[{{0, (-1.2) $CellContext`size$, 0}, {
             0, 1.2 $CellContext`size$, 0}}], 
           
           Arrow[{{0, 0, (-1.2) $CellContext`size$}, {
             0, 0, 1.2 $CellContext`size$}}], 
           Text[
           "\!\(\*\nStyleBox[\"x\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {
            1.2 $CellContext`size$, (-0.05) $CellContext`size$, (-0.05) \
$CellContext`size$}], 
           Text[
           "\!\(\*\nStyleBox[\"y\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {(-0.05) $CellContext`size$, 
             1.2 $CellContext`size$, 0.05 $CellContext`size$}], 
           Text[
           "\!\(\*\nStyleBox[\"z\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {(-0.05) $CellContext`size$, (-0.05) \
$CellContext`size$, 1.2 $CellContext`size$}]}; $CellContext`dwf2 = {Black, 
           PointSize[0.015], 
           Point[{
             $CellContext`x$[$CellContext`t$], 
             $CellContext`y$[$CellContext`t$], 
             $CellContext`z$[$CellContext`t$]}], 
           Thickness[0.005], 
           Arrowheads[0.02], Red, 
           Arrow[{{
              $CellContext`x$[$CellContext`t$], 
              $CellContext`y$[$CellContext`t$], 
              $CellContext`z$[$CellContext`t$]}, \
{$CellContext`x$[$CellContext`t$] + $CellContext`fac$ $CellContext`fx1$$, \
$CellContext`y$[$CellContext`t$] + $CellContext`fac$ $CellContext`fy1$$, \
$CellContext`z$[$CellContext`t$] + $CellContext`fac$ $CellContext`fz1$$}}], 
           Darker[Green, 0.5], 
           Arrow[{{
              $CellContext`x$[$CellContext`t$], 
              $CellContext`y$[$CellContext`t$], 
              $CellContext`z$[$CellContext`t$]}, \
{$CellContext`x$[$CellContext`t$] + $CellContext`fac$ $CellContext`fx2$$, \
$CellContext`y$[$CellContext`t$] + $CellContext`fac$ $CellContext`fy2$$, \
$CellContext`z$[$CellContext`t$] + $CellContext`fac$ $CellContext`fz2$$}}], 
           Blue, 
           Arrow[{{
              $CellContext`x$[$CellContext`t$], 
              $CellContext`y$[$CellContext`t$], 
              $CellContext`z$[$CellContext`t$]}, \
{$CellContext`x$[$CellContext`t$] + $CellContext`fac$ $CellContext`fx3$$, \
$CellContext`y$[$CellContext`t$] + $CellContext`fac$ $CellContext`fy3$$, \
$CellContext`z$[$CellContext`t$] + $CellContext`fac$ $CellContext`fz3$$}}], 
           Dashed, Brown, 
           Line[{{0, 0, 0}, {
              $CellContext`x$[$CellContext`t$], 
              $CellContext`y$[$CellContext`t$], 
              $CellContext`z$[$CellContext`t$]}}]}; $CellContext`dw$ = 
         Graphics3D[{$CellContext`dwf1, $CellContext`dwf2}, PlotRange -> 400, 
           ImageSize -> 400, SphericalRegion -> True, Boxed -> 
           False]; $CellContext`an$ = Animate[
           Evaluate[
            
            ReplaceAll[$CellContext`dw$, {$CellContext`t$ -> \
$CellContext`time}]], {{$CellContext`time, 0, 
             "\!\(\*\nStyleBox[\"t\",\nFontSlant->\"Italic\"]\)"}, \
$CellContext`ts$, $CellContext`te$}, DefaultDuration -> $CellContext`te$, 
           AnimationRunning -> False]; Row[{
           Spacer[50], $CellContext`an$}]], 
      "Specifications" :> {{{$CellContext`fx1$$, 10, 
          Row[{
            Style[
             Subscript[
             "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "x1"], Bold,
              12]}]}, -10, 10, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 1}, {{$CellContext`fy1$$, 10, 
          Row[{
            Style[
             Subscript[
             "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "y1"], Bold,
              12]}]}, -10, 10, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 2}, {{$CellContext`fz1$$, 0, 
          Row[{
            Style[
             Subscript[
             "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "z1"], Bold,
              12]}]}, -10, 10, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 3}, {{$CellContext`fx2$$, -10, 
          Row[{
            Style[
             Subscript[
             "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "x2"], Bold,
              12]}]}, -10, 10, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 4}, {{$CellContext`fy2$$, 10, 
          Row[{
            Style[
             Subscript[
             "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "y2"], Bold,
              12]}]}, -10, 10, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 5}, {{$CellContext`fz2$$, 0, 
          Row[{
            Style[
             Subscript[
             "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "z2"], Bold,
              12]}]}, -10, 10, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 6}, {{$CellContext`fx3$$, -10, 
          Row[{
            Style[
             Subscript[
             "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "x3"], Bold,
              12]}]}, -10, 10, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 7}, {{$CellContext`fy3$$, -10, 
          Row[{
            Style[
             Subscript[
             "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "y3"], Bold,
              12]}]}, -10, 10, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 8}, {{$CellContext`fz3$$, 0, 
          Row[{
            Style[
             Subscript[
             "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "z3"], Bold,
              12]}]}, -10, 10, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 9}, 
        Grid[{{
           Manipulate`Place[1], 
           Manipulate`Place[2], 
           Manipulate`Place[3]}, {
           Manipulate`Place[4], 
           Manipulate`Place[5], 
           Manipulate`Place[6]}, {
           Manipulate`Place[7], 
           Manipulate`Place[8], 
           Manipulate`Place[9]}}, Alignment -> Left, 
         Spacings -> {0.8, 0.4}], {{$CellContext`fr$$, 0, 
          Row[{
            Style[
             Subscript[
             "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "R"], Bold, 
             12]}]}, {1 -> "On", 0 -> "Off"}, ControlType -> RadioButton, 
         ControlPlacement -> 10}, 
        Grid[{{
           Manipulate`Place[10], 
           PaneSelector[{1 -> Row[{
                Spacer[20], 
                Style[
                 Subscript[
                 "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "Rx"], 
                 Bold, 12], 
                Spacer[5], "=", 
                Spacer[5], 
                
                Dynamic[$CellContext`fx1$$ + $CellContext`fx2$$ + \
$CellContext`fx3$$], 
                Spacer[20], 
                Style[
                 Subscript[
                 "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "Ry"], 
                 Bold, 12], 
                Spacer[5], "=", 
                Spacer[5], 
                
                Dynamic[$CellContext`fy1$$ + $CellContext`fy2$$ + \
$CellContext`fy3$$], 
                Spacer[20], 
                Style[
                 Subscript[
                 "\!\(\*\nStyleBox[\"F\",\nFontSlant->\"Italic\"]\)", "Rz"], 
                 Bold, 12], 
                Spacer[5], "=", 
                Spacer[5], 
                
                Dynamic[$CellContext`fz1$$ + $CellContext`fz2$$ + \
$CellContext`fz3$$]}]}, 
            Dynamic[$CellContext`fr$$]], 
           Spacer[20], 
           PaneSelector[{{0, 0, 0} -> Style["Balanced", Bold, 12, 
               RGBColor[0, 
                Rational[2, 3], 0]]}, 
            
            Dynamic[{$CellContext`fx1$$ + $CellContext`fx2$$ + \
$CellContext`fx3$$, $CellContext`fy1$$ + $CellContext`fy2$$ + \
$CellContext`fy3$$, $CellContext`fz1$$ + $CellContext`fz2$$ + \
$CellContext`fz3$$}]]}}]}, "Options" :> {ControlPlacement -> Top}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{907., {470., 479.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>($CellContext`ftsz = 12; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 TextAlignment->Center]
}, Open  ]]
},
WindowSize->{1920, 997},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
Magnification:>1.5 Inherited,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 212, 7, 230, "Title"],
Cell[1701, 44, 353, 9, 74, "Text"],
Cell[2057, 55, 16698, 382, 973, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature ZxDPJzMhAI@CPBgFSsoiPVds *)
